|  | ${ _("Invoice number:") } | ${ pending_return.invoice_number or "-" }
${ _("Sale:") } | ${ pending_return.sale_identifier} | ${ _("Status:") } | ${ pending_return.status_str}
${ _("Returned date:") } | ${ pending_return.return_date.strftime('%x')} | ${ _("Confirm date:") } % if not pending_return.is_pending(): | ${ pending_return.receiving_date.strftime('%x')} % else: | ${ _("Not Received") } % endif
${ _("Received By:") } | ${ pending_return.responsible_name } | ${ _("Confirmed By:") } % if not pending_return.is_pending(): | ${ pending_return.returned_sale.confirm_responsible.person.name } % else: | ${ _("Not Received") } % endif